@@ -5,7 +5,7 @@ from bluedot_rest_framework import import_string
 from django.db.models import F
 
 EventComment = import_string('event.comment.models')
-CommentSerializer = import_string('event.comment.serializers')
+EventCommentSerializer = import_string('event.comment.serializers')
 
 EventCommentLike = import_string('event.comment.like_models')
 EventCommentLikeSerializer = import_string('event.comment.like_serializers')
@@ -37,9 +37,7 @@ class CommentConsumer(WebsocketConsumer):
         state = text_data_json.get('state', 0)
         if state == 0:
             data = {
-                'user_id': text_data_json.get('user_id', None),
                 'unionid': text_data_json.get('unionid', None),
-                'openid': text_data_json.get('openid', None),
                 'nick_name': text_data_json.get('nick_name', None),
                 'avatar_url': text_data_json.get('avatar_url', None),
                 'schedule_id': self.schedule_id,
@@ -62,13 +60,11 @@ class CommentConsumer(WebsocketConsumer):
         elif state == 2:  # 拒绝
             _id = text_data_json.get('id', None)
             event_queryset = EventComment.objects.get(pk=_id)
-            event_queryset.sate = 2
+            event_queryset.state = 2
             event_queryset.save()
         elif state in [3, 4]:  # 点赞
             data = {
-                'user_id': text_data_json.get('user_id', None),
                 'unionid': text_data_json.get('unionid', None),
-                'openid': text_data_json.get('openid', None),
                 'comment_id': text_data_json.get('comment_id', None),
             }
             event_comment_queryset = EventComment.objects.get(
