@@ -1,8 +1,8 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 from .abstract_models import AbstractEventExtend, AbstractEventLive, AbstractEventAddress
 
 
-class AbstractEvent(AbstractEventExtend, AbstractEventLive, AbstractEventAddress):
+class AbstractEvent(AbstractEventExtend, AbstractEventLive, AbstractEventAddress, AbstractRelationTime):
     event_type = models.IntegerField(default=1)
     is_show = models.IntegerField(default=0)
 
@@ -16,9 +16,6 @@ class AbstractEvent(AbstractEventExtend, AbstractEventLive, AbstractEventAddress
     end_time = models.DateTimeField(verbose_name='结束时间')
     module_list = models.JSONField(verbose_name='模块列表')
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
