@@ -1,11 +1,8 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationUser, AbstractRelationTime
 
 
-class AbstractEventRegister(models.Model):
-    user_id = models.IntegerField(null=True)
-    unionid = models.CharField(max_length=100, null=True)
-    openid = models.CharField(max_length=100, null=True)
-    wechat_id = models.IntegerField(null=True)
+class AbstractEventRegister(AbstractRelationUser, AbstractRelationTime):
+
     event_id = models.CharField(max_length=32)
     event_type = models.IntegerField(default=1)
     source = models.IntegerField(default=0)
@@ -19,9 +16,6 @@ class AbstractEventRegister(models.Model):
     job = models.CharField(max_length=100)
     country = models.CharField(max_length=100)
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
