@@ -11,7 +11,7 @@ class AbstractEventSchedule(AbstractRelationTime):
 
     sort = models.IntegerField(default=0)
 
-    speaker_ids = models.JSONField()
+    speaker_ids = models.JSONField(null=True)
 
     class Meta:
         abstract = True
