@@ -1,19 +1,19 @@
 from rest_framework.routers import DefaultRouter
 from bluedot_rest_framework import import_string
 
-EventView = import_string('EVENT.views')
-EventQuestionView = import_string('EVENT.question.views')
-EventQuestionUserView = import_string('EVENT.question.user_views')
-EventScheduleView = import_string('EVENT.schedule.views')
-EventSpeakerView = import_string('EVENT.speaker.views')
-EventDataDownloadView = import_string('EVENT.data_download.views')
-EventRegisterView = import_string('EVENT.register.views')
-EventChatView = import_string('EVENT.chat.views')
-EventConfigurationView = import_string('EVENT.configuration.views')
-EventCommentView = import_string('EVENT.comment.views')
-EventVoteView = import_string('EVENT.vote.views')
-EventVoteUserView = import_string('EVENT.vote.user_views')
-EventVenueView = import_string('EVENT.venue.views')
+EventView = import_string('event.views')
+EventQuestionView = import_string('event.question.views')
+EventQuestionUserView = import_string('event.question.user_views')
+EventScheduleView = import_string('event.schedule.views')
+EventSpeakerView = import_string('event.speaker.views')
+EventDataDownloadView = import_string('event.data_download.views')
+EventRegisterView = import_string('event.register.views')
+EventChatView = import_string('event.chat.views')
+EventConfigurationView = import_string('event.configuration.views')
+EventCommentView = import_string('event.comment.views')
+EventVoteView = import_string('event.vote.views')
+EventVoteUserView = import_string('event.vote.user_views')
+EventVenueView = import_string('event.venue.views')
 
 
 router = DefaultRouter(trailing_slash=False)
