@@ -3,12 +3,12 @@ from rest_framework.response import Response
 from rest_framework import status
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
-from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler, jwt_get_openid_handler
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
 
-EventVote = import_string('EVENT.vote.models')
-EventVoteSerializer = import_string('EVENT.vote.serializers')
-EventVoteUser = import_string('EVENT.vote.user_models')
-EventVoteUserSerializer = import_string('EVENT.vote.user_serializers')
+EventVote = import_string('event.vote.models')
+EventVoteSerializer = import_string('event.vote.serializers')
+EventVoteUser = import_string('event.vote.user_models')
+EventVoteUserSerializer = import_string('event.vote.user_serializers')
 
 
 class EventVoteView(CustomModelViewSet):
@@ -97,9 +97,9 @@ class EventVoteUserView(CustomModelViewSet):
 
     def list(self, request, *args, **kwargs):
         schedule_id = request.query_params.get('schedule_id', None)
-        openid = jwt_get_openid_handler(request.auth)
+        wechat_id = jwt_get_wechatid_handler(request.auth)
         data = self.model_class.objects.filter(
-            schedule_id=schedule_id, openid=openid).first()
+            schedule_id=schedule_id, wechat_id=wechat_id).first()
         if data:
             serializer = self.get_serializer(data)
             return Response({'code': '1', 'data': serializer.data})
