@@ -1,10 +1,9 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class AbstractUser(models.Model):
+class AbstractUser(AbstractRelationTime):
     wechat_id = models.IntegerField(null=True)
     unionid = models.CharField(max_length=100, null=True)
-    openid = models.CharField(max_length=100, null=True)
 
     user_name = models.CharField(max_length=100, null=True)
     first_name = models.CharField(max_length=100, null=True)
@@ -17,9 +16,6 @@ class AbstractUser(models.Model):
     country = models.CharField(max_length=100, null=True)
     source_type = models.CharField(max_length=100, null=True)
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
