@@ -2,7 +2,7 @@ from bluedot_rest_framework.utils.serializers import CustomSerializer
 from rest_framework.serializers import SerializerMethodField
 from bluedot_rest_framework import import_string
 
-User = import_string('USER.models')
+User = import_string('user.models')
 
 
 class UserSerializer(CustomSerializer):
