@@ -1,13 +1,13 @@
-from rest_framework.viewsets import ModelViewSet
+from bluedot_rest_framework.utils.viewsets import CustomModelViewSet
 from .models import WeChatResponseMaterial, WeChatResponseEvent
 from .serializers import WeChatResponseMaterialSerializer, WeChatResponseEventSerializer
 
 
-class WeChatResponseMaterialView(ModelViewSet):
+class WeChatResponseMaterialView(CustomModelViewSet):
     model_class = WeChatResponseMaterial
     serializer_class = WeChatResponseMaterialSerializer
 
 
-class WeChatResponseEventView(ModelViewSet):
+class WeChatResponseEventView(CustomModelViewSet):
     model_class = WeChatResponseEvent
     serializer_class = WeChatResponseEventSerializer
