@@ -1,11 +1,11 @@
 from django.conf.urls import url
 from rest_framework.routers import DefaultRouter
+from bluedot_rest_framework import import_string
 from .response.views import WeChatResponseEventView, WeChatResponseMaterialView
-from .response.response import Response
 from .login.views import WeChatLoginView, WeChatLoginWebSocketView
 from .views import JSSdk, OAuth, Menu, Current
 # from .response.qrcode import WeChatQrcodeView
-
+Response = import_string('wechat.response')
 router = DefaultRouter(trailing_slash=False)
 
 router.register(r'wechat/response/material', WeChatResponseMaterialView,
